# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""SRDP-dependent calibration and imaging notification templates

Revision ID: b7532ce80886
Revises: 5f420090f5b6
Create Date: 2022-02-15 12:32:40.444307

"""
from pathlib import Path

from alembic import op

# revision identifiers, used by Alembic.
from sqlalchemy.orm import Session

# This import can cause issues when trying to do a bare-bones
# alembic command for a fresh revision.   Let the import fail
# quietly, the import will work in the schema container
try:
    from workspaces.notification.schema import NotificationTemplate
except ImportError:
    pass

revision = "b7532ce80886"
down_revision = "5f420090f5b6"
branch_labels = None
depends_on = None


def upgrade():
    session = Session(bind=op.get_bind())

    # add the templates
    cal = NotificationTemplate(
        name="std_calibration_complete",
        description="Sent when calibrations are completed",
        content=(Path.cwd() / "versions" / "templates" / "calibration-2022-02-15.txt").read_text(),
    )
    session.add(cal)
    img = NotificationTemplate(
        name="std_cms_imaging_complete",
        description="Sent when images are completed",
        content=(Path.cwd() / "versions" / "templates" / "imaging-2022-02-15.txt").read_text(),
    )
    session.add(img)
    session.commit()


def downgrade():
    session = Session(bind=op.get_bind())
    cal = session.query(NotificationTemplate).filter_by(name="std_calibration_complete").one()
    session.delete(cal)
    img = session.query(NotificationTemplate).filter_by(name="std_cms_imaging_complete").one()
    session.delete(img)
    session.commit()
